//genesis
/* 
** This simulation script performs 1 simulations :
** mitral cell, antidromic stim. It saves the display every 
** 0.5 msec after the stim, for 20 msec, for using in xwud.
*/

/* Simulation parameters */
float dt = 25e-6
float filet = 500e-6
float framet = 1500e-6
setclock 0 {dt}
setclock 1 {filet}
setclock 2 {framet}
float presavetime=0.0003
float simtime = 0.010
float stimtime = 0.001
float inj = 0.5e-9
str mitcell="mit_trode1.p"
int	frameno = 0
int save_frame = 1

/* Display_mode selects how you want the output.
** 0 : Only file output
** 1 : Xodus output
** 2 : xplot output
*/
int display_mode = 1

/*
** hines_mode is a flag to select the level of optimization for the
** hsolver.
** Level 0 does not use the hines solver.
** Level 1 sets the hines solver to the older (slower) mode.
** Level 2 is the most optimized.
*/
int	hines_mode = 2

maxerrors 80

/*
** Loading in the prototypes
*/
if (!{exists(/library)})
		include defaults
		include compartments
		include bulbchan
	
		ce /library
	
		make_cylind_compartment
		make_LCa3_mit_usb
    	make_K2_mit_usb
    	make_K_mit_usb
		make_KA_bsg_yka
		set KA_bsg_yka Ek -0.07
		make_KM_bsg_upi
		set KM_bsg_upi Ek -0.07
		make_Na_mit_usb
		make_Na2_mit_usb
		make_Ca_mit_conc
		make_Kca_mit_usb
		ce /
end


/*
** Creating the cells 
*/
// Reading in the basic cell descriptor files 
read_cell {mitcell} /mit

// Setting the injection currents
set /mit/axon[11] inject {inj} 

// Setting up the hsolvers
if (hines_mode > 0)
	create hsolve /mit/solve
	set ^ path /mit/##[][TYPE=compartment]

	if (hines_mode == 1)
		set /#/solve comptmode 1 chanmode 1 useconcen 1
	end
	if (hines_mode == 2)
		set /#/solve comptmode 1 chanmode 3 useconcen 1
	end
	if (display_mode==1)
		set /#/solve comptmode 1 chanmode 1 useconcen 1
	end
	call /mit/solve SETUP
	setmethod 11
end

function do_frame
	if (save_frame)
		xwd -name fmit > frame{frameno}
		compress frame{frameno}
		frameno=frameno+1
	end
end

// Setting up the file I/O
create disk_out /output/mitVm
sendmsg /mit/#[][TYPE=compartment] /output/mitVm SAVE Vm
set	/output/# leave_open 1 initialize 1 flush 0
useclock /output/mitVm 1
create script_out /output/frame
set ^ command do_frame
useclock /output/frame 2

// Seting up graphics
if (display_mode==1)
	xstartup
	create xform /gmit [0,700,800,180]
	create xgraph /gmit/graph [0%,0%,100%,100%]
	set /gmit/graph ymin -0.1 ymax 0.05 xmax {simtime}
	sendmsg /mit/soma /gmit/graph PLOT Vm *somaVm *red
	if (save_frame)
		create xform /fmit [338,261,200,200]
	else
		create xform /fmit [0,0,800,700]
	end
	create xdraw /fmit/draw [0%,0%,100%,100%] 
	set ^ wx 0.003 wy 0.003 transform ortho3d vx 0 vy -18 vz 11
	create xcell /fmit/draw/cell
	set /fmit/draw/cell autofat FALSE fatfix TRUE
	set /fmit/draw/cell fatrange 5e-5 fatmax 3e-6 fatmin -1
	set /fmit/draw/cell path /mit/##[][TYPE=compartment] \
		colfield Vm autocol FALSE colmin -0.09 colmax 0.02
	set /fmit/draw/cell rooticon soma.icon
	xshow /fmit
	xshow /gmit
	useclock /fmit 1
end

// Running simulation
reset
set /mit/axon[11] inject 0.0
save_frame=0
step
save_frame=1
step -t {presavetime}
set /mit/axon[11] inject {inj}
step -t {stimtime}
set /mit/axon[11] inject 0.0
// call /mit/solve HPUT /mit/axon[11]
step -t {simtime}


// Flushing pending file output
set /output/mitVm flush 1 leave_open 0
call /output/mitVm PROCESS

// Displaying xplots in mode 2
if (display_mode==2)
	xplot mitVm -geometry =300x300+300+300 &
end

if (display_mode != 1)
	quit
end
