//genesis
/* 
** This simulation script performs 1 simulations :
** mitral cell, antidromic stim. It saves the display every 
** 0.5 msec after the stim, for 20 msec, for using in xwud.
*/

/* Simulation parameters */
float dt = 25e-6
float filet = 100e-6
float framet = 100e-6
setclock 0 {dt}
setclock 1 {filet}
setclock 2 {framet}
float simtime = 0.012
float stimtime = 0.001
float glomtime = 0.006
float inj = 0.5e-9
float glominj = 0.15e-9
float secinj = -0.5e-9
str mitcell="mit_trode1.p"
int	frameno = 0
int save_frame = 1

/* Display_mode selects how you want the output.
** 0 : Only file output
** 1 : Xodus output
** 2 : xplot output
*/
int display_mode = 1

/*
** hines_mode is a flag to select the level of optimization for the
** hsolver.
** Level 0 does not use the hines solver.
** Level 1 sets the hines solver to the older (slower) mode.
** Level 2 is the most optimized.
*/
int	hines_mode = 2

maxerrors 80

/*
** Loading in the prototypes
*/
if (!{exists(/library)})
		include defaults
		include compartments
		include bulbchan
	
		ce /library
	
		make_cylind_compartment
		make_LCa3_mit_usb
    	make_K2_mit_usb
    	make_K_mit_usb
		make_KA_bsg_yka
		set KA_bsg_yka Ek -0.07
		make_KM_bsg_upi
		set KM_bsg_upi Ek -0.07
		make_Na_mit_usb
		make_Na2_mit_usb
		make_Ca_mit_conc
		make_Kca_mit_usb
		ce /
end


/*
** Creating the cells 
*/
// Reading in the basic cell descriptor files 
read_cell {mitcell} /mit
// Setting the injection currents

// Setting up the hsolvers
if (hines_mode > 0)
	create hsolve /mit/solve
	set ^ path /mit/##[][TYPE=compartment]

	if (hines_mode == 1)
		set /#/solve comptmode 1 chanmode 1 useconcen 1
	end
	if (hines_mode == 2)
		set /#/solve comptmode 1 chanmode 3 useconcen 1
	end
	if (display_mode==1)
		set /#/solve comptmode 1 chanmode 1 useconcen 1
	end
	call /mit/solve SETUP
	setmethod 11
end

copy /mit /sec

call /sec/solve DUPLICATE /sec/##[][TYPE=compartment]

copy /mit /glom
call /glom/solve DUPLICATE /glom/##[][TYPE=compartment]

function do_frame
	str time
/*
	if (save_frame)
		xwd -name fmit > allfr{frameno}
		compress allfr{frameno}
		frameno=frameno+1
	end
*/
	time={status(-time)}
	set /clock/t value {time}"  Sec"
end

// Setting up the file I/O
create disk_out /output/mitVm
sendmsg /mit/#[][TYPE=compartment] /output/mitVm SAVE Vm
set	/output/# leave_open 1 initialize 1 flush 0
useclock /output/mitVm 1
create script_out /output/frame
set ^ command do_frame
useclock /output/frame 2

// Seting up graphics
if (display_mode==1)
	xstartup
	create xform /gmit [0,600,800,290]
	create xgraph /gmit/graph [0%,0%,100%,100%]
	set /gmit/graph ymin -0.1 ymax 0.5 xmax {simtime+simtime+glomtime} \
		yoffset 0.1
	sendmsg /mit/soma /gmit/graph PLOT Vm *somaVm *red
	sendmsg /mit/glom11 /gmit/graph PLOT Vm *glomVm *green
	sendmsg /mit/sec_dend112[2] /gmit/graph PLOT Vm *secVm *blue
	sendmsg /glom/glom11 /gmit/graph PLOT Vm *glomVm *green
	sendmsg /sec/sec_dend112[2] /gmit/graph PLOT Vm *secVm *blue
	create xform /fmit [0,0,800,700]
	create xdraw /fmit/draw [0%,0%,100%,100%] 
	set ^ wx 0.003 wy 0.003 transform ortho3d vx 0 vy -18 vz 11 \
		cz 0.0005
	create xcell /fmit/draw/cell
	set ^ path /mit/##[][TYPE=compartment] \
		colfield Vm autocol FALSE colmin -0.15 colmax 0.05
	set /fmit/draw/cell autofat FALSE fatrange 0.0002

	create xdraw /fmit/d2 [0%,0%,15%,40%] 
	set ^ wx 0.00045 wy 0.0012 transform ortho3d vx 0 vy -18 vz 11 \
		cz 0.0002
		
	create xcell /fmit/d2/cell
	set ^ path /glom/##[][TYPE=compartment] \
		colfield Vm autocol FALSE colmin -0.15 colmax 0.05
	set /fmit/d2/cell autofat FALSE fatrange 0.0002

	create xdraw /fmit/d3 [45%,0%,55%,20%] 
	set ^ wx 0.0016 wy 0.0006 transform ortho3d vx 0 vy -18 vz 11 \
		cx 0.0005 cz 0.0002
	create xcell /fmit/d3/cell
	set ^ path /sec/##[][TYPE=compartment] \
		colfield Vm autocol FALSE colmin -0.15 colmax 0.05
	set /fmit/d3/cell autofat FALSE fatrange 0.0002

	create xform /clock [760,600,400,100]
	create xdialog /clock/t [0%,0%,100%,50%] \
		-font -adobe-times-bold-r-normal--34-240-100-100-p-177-iso8859-1
	create xdialog /clock/n [0%,50%,100%,50%] \
	-font -adobe-times-bold-r-normal--34-240-100-100-p-177-iso8859-1 \
	-value " Stimulating Glom"

	xshow /clock
	xshow /fmit
	xshow /gmit
	useclock /fmit/# 1
	useclock /gmit/# 1
end

// Running simulation
reset
set /glom/glom?[] inject {glominj}
set /glom/glom??[] inject {glominj}
save_frame=0

step -t {glomtime}
set /mit/axon[11] inject {inj}
set /glom/glom#[] inject 0.0
set /glom/axon[11] inject {inj}
set /sec/axon[11] inject {inj}
set /sec/sec_dend11[2] inject {secinj} 
save_frame=1
set /clock/n value " Antidromic Pulse"

step -t {stimtime}
set /mit/axon[11] inject 0.0
set /glom/axon[11] inject 0.0
set /sec/axon[11] inject 0.0
// call /mit/solve HPUT /mit/axon[11]
set /clock/n value " Spike propagation"
step -t {simtime}


// Flushing pending file output
set /output/mitVm flush 1 leave_open 0
call /output/mitVm PROCESS

// Displaying xplots in mode 2
if (display_mode==2)
	xplot mitVm -geometry =300x300+300+300 &
end

if (display_mode != 1)
	quit
end
