//genesis
/* 
** This simulation script performs 2 simulations :
** 1 : Granule cell with channels in dends, 5 levels of I.
** 2 : Granule cell with channels in spines
*/

/* Simulation parameters */
float dt = 100e-6
float filet = 100e-6
setclock 0 {dt}
setclock 1 {filet}
float simtime = 0.275
float stimtime = 0.335
float preinjtime = 0.01
float postinjtime = 0.05
float inj1=-0.3e-9
float inj2=-0.2e-9
float inj3=-0.1e-9
float inj4=0.062e-9
float inj5=0.125e-9
str refhi="correct.hi"
str reflo="correct.lo"
str refhyp="correct.hyp"
str grancell="granI_trode1.p"

/* Display_mode selects how you want the output.
** 0 : Only file output
** 1 : Xodus output
** 2 : xplot output
*/
int display_mode = 1

/*
** hines_mode is a flag to select the level of optimization for the
** hsolver.
** Level 0 does not use the hines solver.
** Level 1 sets the hines solver to the older (slower) mode.
** Level 2 is the most optimized.
*/
int	hines_mode = 2

/*
** Loading in the prototypes
*/
if (!{exists(/library)})
		include defaults
		include compartments
		include bulbchan
	
		ce /library
	
		make_cylind_compartment
		make_LCa3_mit_usb
    	make_K2_mit_usb
    	make_K_mit_usb
		make_Na2_rat_smsnn
		make_KA_bsg_yka
		set KA_bsg_yka Ek -0.07
		make_KM_bsg_upi
		set KM_bsg_upi Ek -0.07
		make_Na_mit_usb
		make_Na2_mit_usb
		make_Ca_mit_conc
		make_Kca_mit_usb
		ce /
end

/*
** Creating the cells 
*/
// Reading in the basic cell descriptor files 
read_cell {grancell} /gran
set /gran/soma inject {inj5}

// Setting the injection currents
create neutral /inj_curr 
sendmsg /inj_curr /gran/soma INJECT x

// Setting up the file I/O
create asc_file /output/granVm
set	/output/# leave_open 1 initialize 1 flush 0
sendmsg /gran/soma /output/granVm SAVE Vm
useclock /output/# 1

// Seting up graphics
if (display_mode==1)
	xstartup
	create xform /form [0,0,1000,800]
	create xgraph /form/inj [50%,0%,50%,50%]
	create xgraph /form/gran [50%,50%,50%,50%]
	set /form/inj ymin -5.0e-10 ymax 2.0e-10 xmax {stimtime} overlay 1
	set /form/gran ymin -0.15 ymax 0.02 xmax {stimtime} overlay 1
	sendmsg /inj_curr /form/inj PLOT x *inject *green
	sendmsg /gran/soma /form/gran PLOT Vm *somaVm *red
	xshow /form
	//set /form/inj ymin -5.0e-10 ymax 2.0e-10 xmax {stimtime} overlay 1
	useclock /form/# 1
end

// Setting up the hsolvers
if (hines_mode > 0)
	create hsolve /gran/solve
	set ^ path /gran/##[][TYPE=compartment]

	if (hines_mode == 1)
		set /#/solve comptmode 1 chanmode 1
	end
	if (hines_mode == 2)
		set /#/solve comptmode 1 chanmode 3
	end
	call /gran/solve SETUP
	setmethod 11
end

// Running simulation

function do_sim(inj,name)
	float inj
	str name

	set /output/# flush 0 leave_open 1 initialize 1 filename gran{name}
	reset
	/*
	openfile(granVm,"a"
	writefile granVm /newplot
	writefile granVm /plotname {inj} nA
	closefile(granVm)
	*/
	set /inj_curr x 0.0
	step -t {preinjtime}
	set /inj_curr x {inj}
	step -t {simtime}
	set /inj_curr x 0.0
	step -t {postinjtime}

	// Flushing pending file output
	set /output/# flush 1 leave_open 0
	call /output/# PROCESS
end

do_sim({inj5},"0.125_nA")
do_sim({inj4},"0.062_nA")
do_sim({inj1},"-0.3_nA")
do_sim({inj2},"-0.2_nA")
do_sim({inj3},"-0.1_nA")


// Displaying xplots in mode 2
if (display_mode==2)
	xplot correct.lo correct.hi correct.hyp -geometry =300x300+0+0 &
	xplot granVm -geometry =300x300+300+300 &
end

if (display_mode != 1)
	quit
end
