//genesis
/* 
** This simulation script displays the channel densities of 4
** cell models :
** 1 : Vanilla mitral cell, 
** 2 : Displaced mitral cell
** 3 : Tufted cell,
** 4 : 'turtle' mitral cell,
*/

/* Simulation parameters */
float dt = 50e-6
float filet = 100e-6
setclock 0 {dt}
setclock 1 {filet}
float simtime = 0.32
float inj = 0.5e-9
str refblock="correct.block"
str refnoblock="correct.noblock"
str mitcell="mit.p"
str dmitcell="dmit.p"
str tuftcell="tuft.p"
str tmitcell="tmit.p"
int MODE=1
float CM

function create_scale(name,lo,hi,ndivs,x,y,h)
	str name,lo,hi
	int ndivs,x,y,h
	int dy=ndivs/10

	create xform /{name} [{x},{y},40,{h}]
	create xdraw /{name}/draw [0%,0%,100%,100%]
	ce ^
	set wx 1 wy {ndivs + dy+dy} cy {ndivs/2.0 + dy}
	if (!{exists(/dummy)})
		create neutral /dummy
		if (!{exists(/scalearray)})
			createmap /dummy /scalearray 1 {ndivs}
		end
	end
	create xview scale 
	set ^ path /scalearray/dummy[] field y autoscale TRUE oy {dy}\
		autospace FALSE ny {ndivs - dy}
	create xshape lo -textcolor white -text {lo} -transfmode 1
	set lo ty {dy/2}
	create xshape hi -textcolor white -text {hi} -transfmode 1
	set hi ty {ndivs + dy + dy/2}
	ce /
end

function create_vert_scale(name,lo,hi,bot,top,ndivs)
	str name,lo,hi
	int top,bot,ndivs

	int i
	float y,dy
	if (!{exists(/xproto/draw/hbox)})
		create xshape /xproto/draw/hbox 
		set /xproto/draw/hbox coords [0,0,0][10,0,0] \
			linewidth 2 transfmode 1
	end
	createmap /xproto/draw/hbox {name} {ndivs} 1
	dy=top-bot-40
	dy=dy/ndivs
	y=top+20
	ce {name}
	for (i=1;i<=ndivs;i=i+1)
		set hbox[{i}] ty {y}
		y=y+dy
	end
	create xshape {name}/lo -pixcolor green -text {lo}
	set lo ty {top - 10}
	create xshape {name}/hi -pixcolor red -text {hi}
	set hi ty {bot + 10}
	ce /
end

function create_form(name,x,y,w,h)
	str name
	int x,y,w,h

	create xform /{name} [{x},{y},{w},{h}]
	create xdraw /{name}/draw [0%,0%,100%,100%]
	set ^ wx 0.0028 wy 0.0028 transform ortho3d \
		vx -11 vy -26 vz 24 cx 0.0002
	create xcell /{name}/draw/mit
	set /{name}/draw/mit path /mit/##[][TYPE=compartment] \
		colfield activation autocol TRUE \
		autofat FALSE fatmin -3e-6 fatmax 2e-5 fatrange -10
	// create_vert_scale(/{name}/draw,"0.0","4000.0",0,{h},20)
	create_scale({name}_s,"0","4000.0",50,{x},{y},{h})
	create xshape /{name}/draw/title -textcolor white \
		-text "      Distribution of "{name}" in Mho/sq metre. Sqrt scale" \
		-tz 0.0017
	xshow /{name}
	xshow /{name}_s
	set {name}_s width 40
end

function lin_scale_chdens(path,chan)
	str path
	str chan
	str compt
	float gbar
	float dens
	float cm
	float temp
	float maxdens = 0.0

	foreach compt ({element_list({path})})
		if ({exists({compt}/{chan},Gbar)})
			gbar=get({compt}/{chan},Gbar)
			cm=get({compt},Cm)
			temp=gbar*CM/cm
			dens=temp
			set {compt} activation {dens}
		else
			if ({exists({compt}/{chan},gbar)})
				gbar=get({compt}/{chan},gbar)
				cm=get({compt},Cm)
				temp=gbar*CM/cm
				dens=temp
				set {compt} activation {dens}
			else
				set {compt} activation 0.0
			end
		end
		if (maxdens < temp)
			maxdens=temp
		end
	end
	return({maxdens})
end

function sqrt_scale_chdens(path,chan)
	str path
	str chan
	str compt
	float gbar
	float dens,temp
	float cm
	float maxdens = 0.0

	foreach compt ({element_list({path})})
		if ({exists({compt}/{chan},Gbar)})
			gbar=get({compt}/{chan},Gbar)
			cm=get({compt},Cm)
			temp=gbar*CM/cm
			dens=sqrt({temp})
			set {compt} activation {dens}
		else
			if ({exists({compt}/{chan},gbar)})
				gbar=get({compt}/{chan},gbar)
				cm=get({compt},Cm)
				temp=gbar*CM/cm
				dens=sqrt({temp})
				set {compt} activation {dens}
			else
				set {compt} activation 0.0
			end
		end
		if (maxdens < temp)
			maxdens=temp
		end
	end
	return({maxdens})
end

function log_scale_chdens(path,chan)
	str path
	str chan
	str compt
	float gbar
	float dens,temp
	float cm
	float maxdens = 0.0

	foreach compt ({element_list({path})})
		if ({exists({compt}/{chan},Gbar)})
			gbar=get({compt}/{chan},Gbar)
			cm=get({compt},Cm)
			temp=gbar*CM/cm
			if (maxdens < dens)
				maxdens=dens
			end
			dens=log({100.0*temp})
			set {compt} activation {dens}
		else
			if ({exists({compt}/{chan},gbar)})
				gbar=get({compt}/{chan},gbar)
				cm=get({compt},Cm)
				temp=gbar*CM/cm
				dens=log({100.0*temp})
				set {compt} activation {dens}
			else
				set {compt} activation 0.0
			end
		end
		if (maxdens < temp)
			maxdens=temp
		end
	end
	return({maxdens})
end

function do_update(channel,form)
	str channel
	str form
	int mode
	float maxdens
	int imd
	str smd
	mode={MODE}
	if (mode==0)
		maxdens=lin_scale_chdens(/mit/##[][TYPE=compartment],{channel})
	end
	if (mode==1)
		maxdens=sqrt_scale_chdens(/mit/##[][TYPE=compartment],{channel})
	end
	if (mode==2)
		maxdens=log_scale_chdens(/mit/##[][TYPE=compartment],{channel})
	end
	imd=maxdens
	smd=imd
	set /{form}_s/draw/hi text {smd}
	xupdate /{form}/draw
end

/*
** Loading in the prototypes
*/
if (!{exists(/library)})
		include defaults
		include compartments
		include bulbchan2
	
		ce /library
	
		make_cylind_compartment
		make_LCa3_mit_usb
    	make_K2_mit_usb
    	make_K_mit_usb
		make_Na_rat_smsnn
		make_KA_bsg_yka
		set KA_bsg_yka Ek -0.07
		make_KM_bsg_upi
		set KM_bsg_upi Ek -0.07
		make_Na_mit_usb
		make_Na2_mit_usb
		make_Ca_mit_conc
		make_Kca_mit_usb
		ce /
end


// Reading in the basic cell descriptor files 
read_cell {mitcell} /mit

disable /mit

// Seting up graphics
	xstartup


create_form(Na,0,0,375,400)
create_form(K2,380,0,375,400)
create_form(K,760,0,375,400)
create_form(Ca,0,400,375,400)
create_form(KA,380,400,375,400)
create_form(Kca,760,400,375,400)

do_update(Na_mit_usb,Na)
do_update(K2_mit_usb,K2)
do_update(K_mit_usb,K)
do_update(LCa3_mit_usb,Ca)
do_update(KA_bsg_yka,KA)
do_update(Kca_mit_usb,Kca)
