//genesis
/* 
** This simulation script displays the channel densities of 4
** cell models :
** 1 : Vanilla mitral cell, 
** 2 : Displaced mitral cell
** 3 : Tufted cell,
** 4 : 'turtle' mitral cell,
*/

/* Simulation parameters */
float dt = 50e-6
float filet = 100e-6
setclock 0 {dt}
setclock 1 {filet}
float simtime = 0.32
float inj = 0.5e-9
str refblock="correct.block"
str refnoblock="correct.noblock"
str mitcell="mit.p"
str dmitcell="dmit.p"
str tuftcell="tuft.p"
str tmitcell="tmit.p"
int MODE=1
float CM

function create_form(name,x,y,w,h)
	str name
	int x,y,w,h

	create xform /{name} [{x},{y},{w},{h}]
	create xdraw /{name}/draw [0%,0%,100%,100%]
	set ^ wx 0.0028 wy 0.0028 transform ortho3d \
		vx -11 vy -26 vz 24 cx 0.0002
	create xcell /{name}/draw/mit
	set /{name}/draw/mit path /mit/##[][TYPE=compartment] \
		colfield activation autocol FALSE colmin -0.1 colmax 10.0 \
		autofat FALSE fatfield activation fatmin -0.1 fatmax -0.05 fatrange -2
	xshow /{name}
end

function do_update(form,path)
	str form
	str path

	set {path} activation 0.0
	xupdate /{form}/draw
	set /mit/#[] activation -0.1
end

/*
** Loading in the prototypes
*/
if (!{exists(/library)})
		include defaults
		include compartments
		include bulbchan2
	
		ce /library
	
		make_cylind_compartment
		make_LCa3_mit_usb
    	make_K2_mit_usb
    	make_K_mit_usb
		make_Na_rat_smsnn
		make_KA_bsg_yka
		set KA_bsg_yka Ek -0.07
		make_KM_bsg_upi
		set KM_bsg_upi Ek -0.07
		make_Na_mit_usb
		make_Na2_mit_usb
		make_Ca_mit_conc
		make_Kca_mit_usb
		ce /
end


// Reading in the basic cell descriptor files 
read_cell {mitcell} /mit

disable /mit

// Seting up graphics
	xstartup


create_form(soma,0,0,800,800)
create_form(axon,380,0,800,800)
create_form(primary_dend,760,0,800,800)
create_form(glomerular_tuft,0,400,800,800)
create_form(proximal_secondary_dend,380,400,800,800)
create_form(distal_secondary_dend,760,400,800,800)

set /mit/#[] activation -0.1
do_update(soma,/mit/soma)
do_update(axon,/mit/axon[])
do_update(primary_dend,/mit/primary_dend[])
do_update(glomerular_tuft,/mit/glom#)

set /mit/sec_dend?[] activation 0.0
do_update(proximal_secondary_dend,/mit/sec_dend??[])
set /mit/sec_dend#[] activation 0.0
set /mit/sec_dend?[] activation -0.1
set /mit/sec_dend??[] activation -0.1
do_update(distal_secondary_dend,/mit/sec_dend111)

setpostscript -maxgray 0 -mingray 70 -inverse 1 -dpi 100 -filename ps.out0
echo setpostscript ps.out1
