//genesis
/* 
** This simulation script performs 4 simulations :
** 1 : Vanilla mitral cell, inj=0.5 nA
** 2 : Displaced mitral cell, inj=0.5nA
** 3 : Tufted cell, inj=0.5 nA
** 4 : 'turtle' mitral cell, inj=0.5 nA
*/

/* Simulation parameters */
float dt = 50e-6
float filet = 100e-6
setclock 0 {dt}
setclock 1 {filet}
float simtime = 0.2
float mitinj = 0.5e-9
float dmitinj= 0.4e-9
float tuftinj=0.4e-9
float tmitinj=0.75e-9

float mitinj = -0.5e-9
float dmitinj= -0.5e-9
float tuftinj=-0.5e-9
float tmitinj=-0.5e-9
float mrm,srm
str refblock="correct.block"
str refnoblock="correct.noblock"
str mitcell="mit.p"
str dmitcell="dmit.p"
str tuftcell="tuft.p"
str tmitcell="tmit.p"

/* Display_mode selects how you want the output.
** 0 : Only file output
** 1 : Xodus output
** 2 : xplot output
*/
int display_mode = 1

/*
** hines_mode is a flag to select the level of optimization for the
** hsolver.
** Level 0 does not use the hines solver.
** Level 1 sets the hines solver to the older (slower) mode.
** Level 2 is the most optimized.
*/
int	hines_mode = 2

/*
** Loading in the prototypes
*/
if (!{exists(/library)})
		include defaults
		include compartments
		include bulbchan
	
		ce /library
	
		make_cylind_compartment
		make_LCa3_mit_usb
    	make_K2_mit_usb
    	make_K_mit_usb
		make_Na_rat_smsnn
		make_KA_bsg_yka
		set KA_bsg_yka Ek -0.07
		make_KM_bsg_upi
		set KM_bsg_upi Ek -0.07
		make_Na_mit_usb
		make_Na2_mit_usb
		make_Ca_mit_conc
		make_Kca_mit_usb
		ce /
end


/*
** Creating the cells 
*/
// Reading in the basic cell descriptor files 
read_cell {mitcell} /mit
read_cell {dmitcell} /dmit
read_cell {tuftcell} /tuft
read_cell {tmitcell} /tmit

// Setting the injection currents
mrm=calc_Rm(/mit/soma)
set /mit/soma inject {mitinj} 

srm=calc_Rm(/dmit/soma)
/*
srm=srm*srm/mrm
dmitinj=mitinj*mrm/srm
*/
set /dmit/soma inject {dmitinj} 

srm=calc_Rm(/tuft/soma)
/*
srm=srm*srm/mrm
tuftinj=mitinj*mrm/srm
*/
set /tuft/soma inject {tuftinj} 

srm=calc_Rm(/tmit/soma)
/*
srm=srm*srm/mrm
tmitinj=mitinj*mrm/srm
*/
set /tmit/soma inject {tmitinj} 

echo injections={mitinj},{dmitinj},{tuftinj},{tmitinj}

// Setting up the hsolvers
if (hines_mode > 0)
	create hsolve /mit/solve
	set ^ path /mit/##[][TYPE=compartment]
	create hsolve /dmit/solve
	set ^ path /dmit/##[][TYPE=compartment]
	create hsolve /tuft/solve
	set ^ path /tuft/##[][TYPE=compartment]
	create hsolve /tmit/solve
	set ^ path /tmit/##[][TYPE=compartment]

	if (hines_mode == 1)
		set /#/solve comptmode 1 chanmode 1 useconcen 1
	end
	if (hines_mode == 2)
		set /#/solve comptmode 1 chanmode 3 useconcen 1
	end
	if (display_mode==1)
		set /#/solve comptmode 1 chanmode 1 useconcen 1
	end
	call /mit/solve SETUP
	call /dmit/solve SETUP
	call /tuft/solve SETUP
	call /tmit/solve SETUP
	setmethod 11
end

// Setting up the file I/O
create disk_out /output/hmitVm
create disk_out /output/hdmitVm
create disk_out /output/htuftVm
create disk_out /output/htmitVm
sendmsg /mit/soma /output/hmitVm SAVE Vm
sendmsg /dmit/soma /output/hdmitVm SAVE Vm
sendmsg /tuft/soma /output/htuftVm SAVE Vm
sendmsg /tmit/soma /output/htmitVm SAVE Vm
set	/output/# leave_open 1 initialize 1 flush 0
useclock /output/# 1

// Seting up graphics
if (display_mode==1)
//	set /#/soma dia 0.0000
	xstartup
	create xform /fmit [0,0,900,900]
	create xgraph /fmit/graph [0%,0%,100%,50%]
	set /fmit/graph ymin -0.1 ymax 0.05 xmax {simtime}
	sendmsg /mit/soma /fmit/graph PLOT Vm *somaVm *black
	create xdraw /fmit/draw [0%,0%,100%,100%] 
	set ^ wx 0.0032 wy 0.003 transform ortho3d vx 18 vy -5 vz 11
	create xshape /fmit/draw/axes -coords [0.001,0,0][0,0,0][0,0.001,0][0,0,0][0,0,0.001]
	set /fmit/draw/axes tz -0.0008 ty -0.0014
	create xcell /fmit/draw/cell
	set ^ path /mit/##[][TYPE=compartment] \
		colfield Vm autocol FALSE colmin -0.15 colmax 0.5 \
		fatrange -10 oy 0.00015

	create xform /fdmit [280,0,900,900]
	create xgraph /fdmit/graph [0%,0%,100%,50%]
	set /fdmit/graph ymin -0.1 ymax 0.05 xmax {simtime}
	sendmsg /dmit/soma /fdmit/graph PLOT Vm *somaVm *black
	create xdraw /fdmit/draw [0%,0%,100%,100%]
	set ^ wx 0.0032 wy 0.003 transform ortho3d \
		vx 18 vy -5 vz 11 cx 0.0 cy 0.0 cz 0.0
	create xcell /fdmit/draw/cell
	set ^ path /dmit/##[][TYPE=compartment] colfield Vm \
		colfield Vm autocol FALSE colmin -0.15 colmax 0.5 \
		fatrange -10

	create xform /ftuft [560,0,900,900]
	create xgraph /ftuft/graph [0%,0%,100%,50%]
	set /ftuft/graph ymin -0.1 ymax 0.05 xmax {simtime}
	sendmsg /tuft/soma /ftuft/graph PLOT Vm *somaVm *black
	create xdraw /ftuft/draw [0%,0%,100%,100%]
	set ^ wx 0.0032 wy 0.003 transform ortho3d vx 18 vy -5 vz 11
	create xcell /ftuft/draw/cell
	set ^ path /tuft/##[][TYPE=compartment] colfield Vm \
		colfield Vm autocol FALSE colmin -0.15 colmax 0.5 \
		fatrange -10

	create xform /ftmit [840,0,900,900]
	create xgraph /ftmit/graph [0%,0%,100%,50%]
	set /ftmit/graph ymin -0.1 ymax 0.05 xmax {simtime}
	sendmsg /tmit/soma /ftmit/graph PLOT Vm *somaVm *black
	create xdraw /ftmit/draw [0%,0%,100%,100%]
	set ^ wx 0.0032 wy 0.003 transform ortho3d vx 18 vy -5 vz 11
	create xcell /ftmit/draw/cell
	set ^ path /tmit/##[][TYPE=compartment] colfield Vm \
		colfield Vm autocol FALSE colmin -0.15 colmax 0.5 \
		fatrange -10 oy 0.00015

	xshow /fmit
	xshow /fdmit
	xshow /ftuft
	xshow /ftmit
	useclock /fmit/# 1
	useclock /fdmit/# 1
	useclock /ftuft/# 1
	useclock /ftmit/# 1
	disable /fmit/draw
	disable /fdmit/draw
	disable /ftuft/draw
	disable /ftmit/draw
end

// Running simulation
reset
step -t {simtime}

// Flushing pending file output
set /output/# flush 1 leave_open 0
call /output/# PROCESS

// Displaying xplots in mode 2
if (display_mode==2)
	xplot correct.tuft -geometry =300x300+0+0 &
	xplot correct.notuft -geometry =300x300+300+0 &
	xplot tuftVm -geometry =300x300+0+300 &
	sleep 2
	xplot mitVm -geometry =300x300+300+300 &
	sleep 2
	xplot tmitVm -geometry =300x300+0+600 &
	sleep 2
	xplot dmitVm -geometry =300x300+300+600 &
end

if (display_mode != 1)
	quit
end
