// genesis

/**********************************************************************
**
**	DO NOT EDIT THIS FILE IN THE neurokit DIRECTORY!
**
**	Make a copy of this file in every directory that contains .p
**	files and edit the copies, in order to customize neurokit for
**	different simulations. When you run neurokit from other
**	directories, the simulator will look for the local version of
**	userprefs.g, and if it cannot find it there will look for the
**	default in the neurokit directory. This version of userprefs is
**	set up to run the Coarse Asymmetric Mitral cell demo.
**	
**	There are three aspects to customisation :
**	
**	1	Include the appropriate script files from the /neuron/prototype
**		directory and from wherever you have defined new prototype
**		elements.
**
**	2	Invoke the functions that make the prototypes you want for
**		your simulation.
**
**	3	Put your preferences for the user_variables defined in
** 		defaults.g in the copies of this file.
**
**********************************************************************/

echo Using default user preferences!

/**********************************************************************
**
**	1	Including script files for prototype functions
**
**********************************************************************/

	include defaults
	include compartments
	include bulbchan3

	ce /library

    make_cylind_compartment
    make_LCa3_mit_usb
    make_Na2_rat_smsnn
    make_KA_bsg_yka
    set KA_bsg_yka Ek -0.07
    make_KM_bsg_upi
	copy KM_bsg_upi KM_bsg_yka
    make_K_mit_usb
    make_K2_mit_usb
	make_K_slow_usb
    make_Na_mit_usb
    make_Na2_mit_usb
	make_glu_mit_usb
	make_GABA_1_mit_usb
	make_GABA_2_mit_usb
	make_glu_gran_usb
	make_glu_pg_usb
	make_olf_receptor
	make_spike
	make_Ca_mit_conc
	make_Kca_mit_usb

/**********************************************************************
**
**	3	Setting preferences for user-variables.
**
**********************************************************************/

/* See defaults.g for default values of these. Put your preferred
values for these in your copy of userprefs in the directory where
you are running your simulations from. */

 /* xcell widget */
 user_wx = 1.4e-3
 user_wy = 1.4e-3
 user_field1 = "Vm"
 user_path1 = "."
 user_colmin1 = -0.10
 user_colmax1 = 0.05
user_fatrange1 = 0.000001
 user_fatfix1 = 0
 user_colfix1 = 0
 user_numxouts = 1	/* show 1 or 2 xout and graph windows */
 user_field2 = "Vm"
 user_path2 = "."
 user_colmin2 = -0.10
 user_colmax2 = 0.05
 user_fatrange2 = -40.0
 user_fatfix2 = 0
 user_colfix2 = 0

 /* xgraph widget */
 user_xmax1 = 0.5
 user_ymin1 = -0.1
 user_ymax1 = 0.05
 user_yoffset1 = 0.10
 user_xmax2 = 0.5
 user_ymin2 = -0.1
 user_ymax2 = 0.05
 user_yoffset2 = 0.10

 /* cell_run_control widget */
  /* integration */
 user_symcomps = 0	/* boolean, default is asymmetric comps */
 user_intmethod = 0
 user_runtime = 0.5

  /* electrophysiology */
 user_inject = 1.0
 user_clamp = 0.0
 user_rate = 100.0
 user_weight = 100.0
 user_activ = 1000.0
 user_spike = 0.1
user_syntype1 = "glu_mit_upi"
user_syntype2 = "GABA_mit_upi"


  /* simulation output : file_IO widget */
 user_filepath = "../results"
 user_restorefile = "restore_camit"
 user_filefield = "Vm"
 user_filefieldpath = "soma"
 user_filename = "testVm"
 user_dt = 1.0e-5 
 user_refresh = 10.0

 /* Cell specifications : file_form widget */
 user_cell = "/pg"
 user_pfile = "pg.p"
 user_name = "Me"

/*
 Set screen width preferences here.
 Decstation 5000/200 : 1280
 Most other workstations : 1150
*/

 user_screenwidth = 1150

 if (exists(/xproto))
 	/* appropriate for black and white printing */
 	setpostscript -mingray 255 -maxgray 256 -inverse 0
 	/* appropriate for printing out shades of grey */
 	setpostscript -mingray 20 -maxgray 120 -inverse 0
 end


/*****************************************************************************/
