//genesis

/***********************************************************************
**                                                                    **
**	  Compartments.g : compartment definition file, neuron builder kit**
**                                                                    **
**      By E. De Schutter, Nov 1990                                   **
******************************************************************************/

/* FUNCTIONS TO MAKE DEFAULT LIBRARY COMPARTMENTS */
/* Note the use of environment variables Len(gth) and Dia(meter)
**	these should always be present in /library definitions of
**	compartments, otherwise scaling of conductance_Gbars and 
**	pool_volumes in .p-files may not be correct and the
**	*spherical options in the parsing routines will not work! 
** A Len(gth) == 0.0 makes the (sym)compartment spherical to the
**	parsing routines, if you want to use the *spherical
**	routines the library must contain prototypes for spherical
**	compartments.  They should be named ..._sphere.
** Note also that all copies of these library compartments
**	keep the original Len and Dia values */

function make_cylind_compartment
	float	len = 100.0e-6
	str		Len = "100.0e-6"
	float	dia = 2.0e-6
	str		Dia = "2.0e-6"
	float surface = len * dia * PI

	if (!{exists(compartment)})
		create	compartment compartment
	end
	set compartment \
		Cm		{CM * surface} \		// F
		Ra		{4.0*RA*len / (dia*dia*PI)} \	// ohm
		Em  	{EREST_ACT} \			// V
		Rm		{RM / surface} \ 		// ohm
		inject		0.0
	set -env compartment \
		Len		{Len}	 \				// m, >0 is cylinder
		Dia		{Dia}					// m
end

function make_sphere_compartment
	float	dia = 20.0e-6
	str		Dia = "20.0e-6"
	float surface = dia * dia * PI

	if (!{exists(compartment_sphere)})
		create	compartment compartment_sphere
	end
	set compartment_sphere \
		Cm		{CM * surface} \	// F
		Ra		{8.0*RA / (dia*PI)} \	// ohm
		Em  	{EREST_ACT} \			// V
		Rm		{RM / surface} \ 		// ohm
		inject		0.0
	set -env compartment_sphere \
		Len		"0.0"	 \				// m, =0 is sphere
		Dia		{Dia}					// m
end

function make_cylind_symcompartment
	float	len = 100.0e-6
	str		Len = "100.0e-6"
	float	dia = 2.0e-6
	str		Dia = "2.0e-6"
	float surface = len * dia * PI

	if (!{exists(symcompartment)})
		create	symcompartment symcompartment
	end
	set symcompartment \
		Cm		{CM * surface} \		// F
		Ra		{4.0*RA*len / (dia*dia*PI)} \	// ohm
		Em  	{EREST_ACT} \			// V
		Rm		{RM / surface} \ 		// ohm
		inject		0.0
	set -env symcompartment \
		Len		{Len}	 \				// m, >0 is cylinder
		Dia		{Dia}					// m
end

function make_sphere_symcompartment
	float	dia = 20.0e-6
	str		Dia = "20.0e-6"
	float surface = dia * dia * PI

	if (!{exists(symcompartment_sphere)})
		create	symcompartment symcompartment_sphere
	end
	set symcompartment_sphere \
		Cm		{CM * surface} \		// F
		Ra		{8.0*RA / (dia*PI)} \	// ohm
		Em  	{EREST_ACT} \			// V
		Rm		{RM / surface} \ 		// ohm
		inject		0.0
	set -env symcompartment_sphere \
		Len		"0.0"	 \				// m, =0 is sphere
		Dia		{Dia}					// m
end
