//genesis
/* 
** This simulation script performs 4 simulations :
** 1 Type I granule cell, usual curr inj
** 2 Type II granule cell, usual curr inj
** 3 Type III granule cell, usual curr inj
** 4 Granule cell without trode, usual curr inj (?)
*/

/* Simulation parameters */
float dt = 50e-6
float filet = 400e-6
setclock 0 {dt}
setclock 1 {filet}
float simtime = 0.2
float inj = -0.1e-9
str refblock="correct.block"
str refnoblock="correct.noblock"
str granIcell="granI.p"
str granIIcell="granII.p"
str granIIIcell="granIII.p"

/* Display_mode selects how you want the output.
** 0 : Only file output
** 1 : Xodus output
** 2 : xplot output
*/
int display_mode = 1

/*
** hines_mode is a flag to select the level of optimization for the
** hsolver.
** Level 0 does not use the hines solver.
** Level 1 sets the hines solver to the older (slower) mode.
** Level 2 is the most optimized.
*/
int	hines_mode = 2

/*
** Loading in the prototypes
*/
if (!{exists(/library)})
		include defaults
		include compartments
		include bulbchan2
	
		ce /library
	
		make_cylind_compartment
		make_LCa3_mit_usb
    	make_K2_mit_usb
    	make_K_mit_usb
		make_Na2_rat_smsnn
		make_KA_bsg_yka
		set KA_bsg_yka Ek -0.07
		make_KM_bsg_upi
		set KM_bsg_upi Ek -0.07
		make_Na_mit_usb
		make_Na2_mit_usb
		make_Ca_mit_conc
		make_Kca_mit_usb
		ce /
end


/*
** Creating the cells 
*/
// Reading in the basic cell descriptor files 
read_cell {granIcell} /granI
read_cell {granIIcell} /granII
read_cell {granIIIcell} /granIII

// Setting the injection currents
set /#/soma inject {inj} 

// Setting up the hsolvers
if (hines_mode > 0)
	create hsolve /granI/solve
	set ^ path /granI/##[][TYPE=compartment]
	create hsolve /granII/solve
	set ^ path /granII/##[][TYPE=compartment]
	create hsolve /granIII/solve
	set ^ path /granIII/##[][TYPE=compartment]

	if (hines_mode == 1)
		set /#/solve comptmode 1 chanmode 1 useconcen 1
	end
	if (hines_mode == 2)
		set /#/solve comptmode 1 chanmode 3 useconcen 1
	end
	if (display_mode==1)
		set /#/solve comptmode 1 chanmode 1 useconcen 1
	end
	call /granI/solve SETUP
	call /granII/solve SETUP
	call /granIII/solve SETUP
	setmethod 11
end

// Setting up the file I/O
create disk_out /output/granIVm
	set ^ filename hgIVm
create disk_out /output/granIIVm
	set ^ filename hgIIVm
create disk_out /output/granIIIVm
	set ^ filename hgIIIVm
sendmsg /granI/soma /output/granIVm SAVE Vm
sendmsg /granII/soma /output/granIIVm SAVE Vm
sendmsg /granIII/soma /output/granIIIVm SAVE Vm
set	/output/# leave_open 1 initialize 1 flush 0
useclock /output/# 1

// Seting up graphics
if (display_mode==1)
	xstartup
	create xform /fgranI [0,0,700,700]
	create xgraph /fgranI/graph [0%,0%,100%,100%]
	set /fgranI/graph ymin -0.1 ymax 0.05 xmax {simtime}
	sendmsg /granI/soma /fgranI/graph PLOT Vm *somaVm *black
	create xdraw /fgranI/draw [0%,0%,100%,100%] 
	set ^ wx 0.0006 wy 0.0006 transform ortho3d \
		cz 2.1e-4 vx 18 vy 9 vz 11
	create xcell /fgranI/draw/cell
	set ^ path /granI/##[][TYPE=compartment] \
		colfield Vm autocol FALSE colmin 0.15 colmax 20.25 \
		autofat FALSE fatmin 0.5e-6 fatmax 4e-6 fatrange -10
	create xshape /fgranI/draw/axes -coords [0.0001,0,0][0,0,0][0,0.0001,0][0,0,0][0,0,0.0001]
	set /fgranI/draw/axes tz 0.0002 tx 0.0003

	create xform /fgranII [330,0,700,700]
	create xgraph /fgranII/graph [0%,0%,100%,100%]
	set /fgranII/graph ymin -0.1 ymax 0.05 xmax {simtime}
	sendmsg /granII/soma /fgranII/graph PLOT Vm *somaVm *black
	create xdraw /fgranII/draw [0%,0%,100%,100%]
	set ^ wx 0.0006 wy 0.0006 transform ortho3d \
		cz 2.1e-4 vx 18 vy 9 vz 11
	create xcell /fgranII/draw/cell
	set ^ path /granII/##[][TYPE=compartment] colfield Vm \
		colfield Vm autocol FALSE colmin 0.15 colmax 20.25 \
		autofat FALSE fatmin 0.5e-6 fatmax 4e-6 fatrange -10

	create xform /fgranIII [660,0,700,700]
	create xgraph /fgranIII/graph [0%,0%,100%,50%]
	set /fgranIII/graph ymin -0.1 ymax 0.05 xmax {simtime}
	sendmsg /granIII/soma /fgranIII/graph PLOT Vm *somaVm *black
	create xdraw /fgranIII/draw [0%,0%,100%,100%]
	set ^ wx 0.0006 wy 0.0006 transform ortho3d \
		cz 2.1e-4 vx 18 vy 9 vz 11
	create xcell /fgranIII/draw/cell
	set ^ path /granIII/##[][TYPE=compartment] colfield Vm \
		colfield Vm autocol FALSE colmin 0.15 colmax 20.25 \
		autofat FALSE fatmin 0.5e-6 fatmax 4e-6 fatrange -10

	xshow /fgranI
	xshow /fgranII
	xshow /fgranIII
	useclock /fgranI/# 1
	useclock /fgranII/# 1
	useclock /fgranIII/# 1
	disable /fgranI/draw
	disable /fgranII/draw
	disable /fgranIII/draw
end


// Running simulation
reset
step -t {simtime}

// Flushing pending file output
set /output/# flush 1 leave_open 0
call /output/# PROCESS

// Displaying xplots in mode 2
if (display_mode==2)
	xplot granIVm -geometry =300x300+300+300 &
	sleep 2
	xplot granIIIVm -geometry =300x300+0+600 &
	sleep 2
	xplot granIIVm -geometry =300x300+300+600 &
end

if (display_mode != 1)
	quit
end
