//genesis
/* 
** This simulation script performs 5 simulations :
** 1 : Granule cell with channels in dends, 5 levels of I.
** 2 : Granule cell with channels in spines
** 3 : Granule cell without electrode leak in soma
** 4 : Granule cell model 2
** 5 : Granule cell model 3
*/

/* Simulation parameters */
float dt = 100e-6
float filet = 100e-6
float grapht = 500e-6
setclock 0 {dt}
setclock 1 {filet}
setclock 2 {grapht}
float injtime = 0.275
float preinjtime = 0.00
float postinjtime = 0.3833-0.275
float simtime = injtime+preinjtime+postinjtime
float inj1=-0.3e-9
float inj2=-0.2e-9
float inj3=-0.1e-9
float inj4=0.062e-9
float inj5=0.125e-9
str refhi="correct.hi"
str reflo="correct.lo"
str refhyp="correct.hyp"
str grancell="granI_trode1.p"
str spinecell="R30spinechan.p"
str granmoda="R30.p"
str granmodb="R29.p"
str granmodc="R18.p"
float temp

/* Display_mode selects how you want the output.
** 0 : Only file output
** 1 : Xodus output
** 2 : xplot output
*/
int display_mode = 1

/*
** hines_mode is a flag to select the level of optimization for the
** hsolver.
** Level 0 does not use the hines solver.
** Level 1 sets the hines solver to the older (slower) mode.
** Level 2 is the most optimized.
*/
int	hines_mode = 2

/*
** Loading in the prototypes
*/
if (!{exists(/library)})
		include defaults
		include compartments
		include bulbchan
	
		ce /library
	
		make_cylind_compartment
		/*
		make_LCa3_mit_usb
    	make_K2_mit_usb
		*/
    	make_K_mit_usb
		make_Na2_rat_smsnn
		make_KA_bsg_yka
		set KA_bsg_yka Ek -0.07
		make_KM_bsg_upi
		set KM_bsg_upi Ek -0.07
		make_Na_mit_usb
		/*
		make_Na2_mit_usb
		make_Ca_mit_conc
		make_Kca_mit_usb
		*/
		ce /
end

/*
** Creating the cells 
*/
// Reading in the basic cell descriptor files 
read_cell {granmoda} /grana
read_cell {granmodb} /granb
read_cell {granmodc} /granc
set /grana/soma inject {inj5}
set /granb/soma inject {inj5}
set /granc/soma inject {inj5}

copy /grana /noleak
temp=get(/noleak/soma,Cm)
temp=RM*CM/temp
set /noleak/soma Rm {temp}

read_cell {spinecell} /sp
set /sp/soma inject {inj5}
// Setting up the channel conductances in the spines to equal the
// old conductances in their parent dends, and setting that to zero.
str chan
str name
str compt
float gbar

foreach chan ({EL(/sp/#[]/#[TYPE=tabchannel])})
	gbar=get({chan},Gbar)
	name=get({chan},name)
	foreach compt ({EL({chan}/../#[TYPE=compartment])})
		set {compt}/{name} Gbar {gbar/8.0}
		set {chan} Gbar 0.0
	end
end

// Setting the injection currents
create neutral /inj_curr 
sendmsg /inj_curr /grana/soma INJECT x
sendmsg /inj_curr /granb/soma INJECT x
sendmsg /inj_curr /granc/soma INJECT x
sendmsg /inj_curr /sp/soma INJECT x
sendmsg /inj_curr /noleak/soma INJECT y

// Setting up the file I/O
create asc_file /output/granaVm
create asc_file /output/granbVm
create asc_file /output/grancVm
create asc_file /output/spVm
create asc_file /output/noleakVm
set	/output/# leave_open 1 initialize 1 flush 0
sendmsg /grana/soma /output/granaVm SAVE Vm
sendmsg /granb/soma /output/granbVm SAVE Vm
sendmsg /granc/soma /output/grancVm SAVE Vm
sendmsg /sp/soma /output/spVm SAVE Vm
sendmsg /noleak/soma /output/noleakVm SAVE Vm
useclock /output/# 1

// Seting up graphics
if (display_mode==1)
	xstartup
	create xform /form [0,0,1000,800]
	create xgraph /form/inj [50%,0%,50%,30%]
	create xgraph /form/grana [50%,0%,50%,30%]
	create xgraph /form/granb [0%,30%,50%,30%]
	create xgraph /form/granc [50%,30%,50%,30%]
	create xgraph /form/sp [0%,60%,50%,30%]
	create xgraph /form/noleak [50%,60%,50%,30%]
	set /form/inj ymin -5.0e-10 ymax 2.0e-10 xmax {simtime} overlay 1
	set /form/grana ymin -0.15 ymax 0.03 xmax {simtime} overlay 1
	set /form/granb ymin -0.15 ymax 0.03 xmax {simtime} overlay 1
	set /form/granc ymin -0.15 ymax 0.03 xmax {simtime} overlay 1
	set /form/sp ymin -0.15 ymax 0.03 xmax {simtime} overlay 1
	set /form/noleak ymin -0.20 ymax 0.03 xmax {simtime} overlay 1
	sendmsg /inj_curr /form/inj PLOT x *inject *green
	sendmsg /grana/soma /form/grana PLOT Vm *somaVm *red
	sendmsg /granb/soma /form/granb PLOT Vm *somaVm *red
	sendmsg /granc/soma /form/granc PLOT Vm *somaVm *red
	sendmsg /sp/soma /form/sp PLOT Vm *somaVm *blue
	sendmsg /noleak/soma /form/noleak PLOT Vm *somaVm *orange
	xshow /form
	useclock /form/# 2
end

// Setting up the hsolvers
if (hines_mode > 0)
	create hsolve /grana/solve
	set ^ path /grana/##[][TYPE=compartment]

	if (hines_mode == 1)
		set /#/solve comptmode 1 chanmode 1
	end
	if (hines_mode == 2)
		set /#/solve comptmode 1 chanmode 3
	end
	call /grana/solve SETUP

	create hsolve /granb/solve
	set ^ path /granb/##[][TYPE=compartment]

	if (hines_mode == 1)
		set /#/solve comptmode 1 chanmode 1
	end
	if (hines_mode == 2)
		set /#/solve comptmode 1 chanmode 3
	end
	call /granb/solve SETUP

	create hsolve /granc/solve
	set ^ path /granc/##[][TYPE=compartment]

	if (hines_mode == 1)
		set /#/solve comptmode 1 chanmode 1
	end
	if (hines_mode == 2)
		set /#/solve comptmode 1 chanmode 3
	end
	call /granc/solve SETUP

	create hsolve /sp/solve
	set ^ path /sp/##[][TYPE=compartment]

	if (hines_mode == 1)
		set /#/solve comptmode 1 chanmode 1
	end
	if (hines_mode == 2)
		set /#/solve comptmode 1 chanmode 3
	end
	call /sp/solve SETUP
	create hsolve /noleak/solve
	set ^ path /noleak/##[][TYPE=compartment]

	if (hines_mode == 1)
		set /#/solve comptmode 1 chanmode 1
	end
	if (hines_mode == 2)
		set /#/solve comptmode 1 chanmode 3
	end
	call /noleak/solve SETUP
	setmethod 11
end

// Running simulation

function do_sim(inj,name)
	float inj
	str name

	set /output/granaVm flush 0 leave_open 1 initialize 1 filename grana{name}
	set /output/granbVm flush 0 leave_open 1 initialize 1 filename granb{name}
	set /output/grancVm flush 0 leave_open 1 initialize 1 filename granc{name}
	set /output/spVm flush 0 leave_open 1 initialize 1 filename sp{name}
	set /output/noleakVm flush 0 leave_open 1 initialize 1 filename noleak{name}
	reset

	set /inj_curr x 0.0 y 0.0
	step -t {preinjtime}
	set /inj_curr x {inj} y {inj/2.0}
	step -t {injtime}
	set /inj_curr x 0.0	y 0.0
	step -t {postinjtime}

	// Flushing pending file output
	set /output/# flush 1 leave_open 0
	call /output/# PROCESS
end

do_sim({inj5},"0.125_nA")
do_sim({inj4},"0.062_nA")
do_sim({inj1},"-0.3_nA")
do_sim({inj2},"-0.2_nA")
do_sim({inj3},"-0.1_nA")


// Displaying xplots in mode 2
if (display_mode==2)
	xplot correct.lo correct.hi correct.hyp -geometry =300x300+0+0 &
	xplot granaVm -geometry =300x300+300+300 &
end

if (display_mode != 1)
	quit
end
