//genesis
/* Options :
** n11 : Remove Na, K2 from gloms
** n12 : Add K as a free param, but it scales uniformly over cell
**       because eff on a single chan type should be constt
**		 For cell with no Na,K2 in glom
** n13 : As n11, but fixed elmlist bug and changed block model to p49
** n13 : As n12, but fixed elmlist bug and changed block model to p49
** Remove the axonal chans from range because we need them
** Use 2x K
** Include K in search
** Scale axonal channels together
** Change weightings as match improves
*/

float EPSILON = 1.0e-20
int STARTSIM=0
int ENDSIM=59049


float dt = 50e-6
float filet = 100e-6
float simtime = 0.32
float inj = 0.5e-9
str scale = "1.0"
int nloops
str reffile="correct.noblock"
int	hinesmode = 2
str res_id="n14"
int chmode= 1
str cellfile="n14"
int NGRID=3
int NPARMS=11
float TOLERANCE=0.001

function generate_parms
	int i
	int iscale
	float scale
	float Na_s,K2_s	// soma
	float Na_a,K2_a	// axon
	float Na_g,K2_g	// glom
	float Na_p,K2_p	// prim dend
	float Na_psec,K2_psec	// sec dend prox
	float Na_dsec,K2_dsec	// sec dend dist
	float K_all

	for (i=0;i<NPARMS;i=i+1)
		scale=get(/parms,table->table[{i}])
		if (i==0)
			Na_a=scale
		end
		if (i==1)
			K2_a=scale
		end

		if (i==2)
			Na_s=scale
		end
		if (i==3)
			K2_s=scale
		end

		if (i==4)
			Na_p=scale
		end
		if (i==5)
			K2_p=scale
		end

		if (i==6)
			Na_psec=scale
		end
		if (i==7)
			K2_psec=scale
		end

		if (i==8)
			Na_dsec=scale
		end
		if (i==9)
			K2_dsec=scale
		end

		if (i==10)
			K_all=scale
		end
	end

	scale_parms(/mit/soma,/proto/mit/soma, \
		Na_mit_usb,Gbar,{Na_s}, \
		K2_mit_usb,Gbar,{K2_s})

	scale_parms(/mit/axon[],/proto/mit/axon[], \
		Na_mit_usb,Gbar,{Na_a}, \
		K2_mit_usb,Gbar,{K2_a})

	scale_parms(/mit/primary_dend[],/proto/mit/primary_dend[], \
		Na_mit_usb,Gbar,{Na_p}, \
		K2_mit_usb,Gbar,{K2_p})

	scale_parms(/mit/sec_dend#[],/proto/mit/sec_dend#[], \
		Na_mit_usb,Gbar,{Na_dsec}, \
		K2_mit_usb,Gbar,{K2_dsec})

	scale_parms(/mit/sec_dend?[],/proto/mit/sec_dend?[], \
		Na_mit_usb,Gbar,{Na_psec}, \
		K2_mit_usb,Gbar,{K2_psec})
	scale_parms(/mit/sec_dend??[],/proto/mit/sec_dend??[], \
		Na_mit_usb,Gbar,{Na_psec}, \
		K2_mit_usb,Gbar,{K2_psec})

	scale_parms(/mit/#[],/proto/mit/#[], \
		K_mit_usb,Gbar,{K_all})
end

function main_loop(cell)
	str cell
	str resfile
	str datafile
	int	i
	int	ret

	float match
	float lastbest=100
	int	loopno

	str region_str
	str chan_str

	setclock 0 {dt}
	setclock 1 {filet}
	

	float_format %0.20g


	if (!{exists(/output/mitVm)})
		create asc_file /output/mitVm
	end

	create table /parms
	call /parms TABCREATE 100 0 100
	disable /parms

	useclock /output/mitVm 1

	read_cell {cell}.p /mit
	copy /mit /proto
	
   	datafile = "Vm." + {res_id}
   	resfile = {res_id} + ".results"
	if (0==0)
   		openfile({resfile},"a")
    		writefile {resfile}
    		writefile {resfile} {date}
    		writefile {resfile}  Cell input res = {calc_Rm(/mit/soma)}
    		writefile {resfile}  Approx Cell cap = {calc_Cm(/mit)}
    		writefile {resfile}  notes : scale = {scale}, inj = {inj}
    		writefile {resfile}
			writefile {resfile} storing plots in {datafile}
		closefile({resfile})
	end


	sendmsg /mit/soma /output/mitVm SAVE Vm
	set /output/mitVm filename {datafile}

	nloops=0
	while(1)
		nloops = nloops + 1
		set	/output/# leave_open 1 initialize 1 flush 0
		set /mit/soma inject {inj}
		if (exists(/mit/solve))
			delete /mit/solve
		end
		/* ret=nmin({NPARMS},/parms,{match},-exp,-t,{TOLERANCE}) */
		ret=splinmin({NPARMS},/parms,{match},-exp,-t,{TOLERANCE})
		if(ret==1)
   			openfile({resfile},"a")
			writefile {resfile} final match = {get(/parms,output)} took {nloops} evaluations
			for(i=0;i<NPARMS;i=i+1)
				writefile {resfile} {i} {get(/parms,table->table[{i}])}
			end
			closefile({resfile})
			break
		end
		generate_parms
		reset
		create hsolve /mit/solve
		if (hinesmode == 1)
			set /mit/solve comptmode 1 chanmode {chmode} \
				path /mit/##[][TYPE=compartment]
		end
		if (hinesmode == 2)
			set /mit/solve comptmode 1 chanmode 3 useconcen 1 \
				path /mit/##[][TYPE=compartment]
		end
		call /mit/solve SETUP
		setmethod 11

		reset
		step -t {simtime}
		/* To get rid of the pending output */
		set /output/# flush 1 leave_open 0
		call /output/# PROCESS
		match=curvematch({reffile},{datafile},-w,2.0,2.0,0.5,0.2)
   		openfile({resfile},"a")
		writefile {resfile} {nloops} {match}
		if (match < lastbest)
			for(i=0;i<NPARMS;i=i+1)
				writefile {resfile} {i} {get(/parms,table->table[{i}])}
			end
			lastbest=match
			cp {datafile} {datafile}.{nloops}
			status -process
		end
		closefile({resfile})
		echo {resfile} {nloops} match={match}
		/*
		*/
	end
	openfile({resfile},"a")
	writefile {resfile}
	writefile {resfile}
	writefile {resfile} {nloops} {match}
	for(i=0;i<NPARMS;i=i+1)
		writefile {resfile} {i} {get(/parms,table->table[{i}])}
	end
	writefile {resfile}
	closefile({resfile})
end
	
	

	if (!{exists(/library)})
		include defaults
		include compartments
		include bulbchan2
	
		ce /library
	
		make_cylind_compartment
		make_LCa3_mit_usb
    	make_K2_mit_usb
    	make_K_mit_usb
		make_Na_rat_smsnn
		make_KA_bsg_yka
		set KA_bsg_yka Ek -0.07
		make_KM_bsg_upi
		set KM_bsg_upi Ek -0.07
		make_Na_mit_usb
		make_Na2_mit_usb
		make_Ca_mit_conc
		make_Kca_mit_usb
        /* Trying to correct the level of the spike thresholds */
		set LCa3_mit_usb    Ek 0.06
		set Ca_mit_conc Ca_base 0.000005 tau 0.015

		/*
        set LCa3_mit_usb    X_A->ox 0.005   X_B->ox 0.005   \
                            Y_A->ox 0.005   Y_B->ox 0.005
        set K_mit_usb       X_A->ox 0.005   X_B->ox 0.005   \
                            Y_A->ox 0.005   Y_B->ox 0.005
        set KA_bsg_yka      X_A->ox 0.005   X_B->ox 0.005   \
                            Y_A->ox 0.005   Y_B->ox 0.005
        set Kca_mit_usb/qv  table->ox 0.005
		*/
		ce /
	end
if (0==0)
	status -process
end
main_loop({cellfile})

if (0==0)
	status -process
end
quit
