//genesis
/* 
** This simulation script performs 1 simulation :
** mitral cell, time_course when a depol or hpol curr stim is
** given over a depol constt curr stim which is too lo for spiking.
*/

/* Simulation parameters */
float dt = 100e-6
float filet = 200e-6
setclock 0 {dt}
setclock 1 {filet}
float prestimtime = 0.3
float stimduration = 0.002
float poststimtime = 0.2
float simtime = prestimtime+stimduration*2.0+poststimtime*2.0
float const_inj = 0.2e-9
float bliphi = 2.0e-9
float bliplo = -5.0e-9
str mitcell="mit_trode1.p"

/* Display_mode selects how you want the output.
** 0 : Only file output
** 1 : Xodus output
** 2 : xplot output
*/
int display_mode = 1

/*
** hines_mode is a flag to select the level of optimization for the
** hsolver.
** Level 0 does not use the hines solver.
** Level 1 sets the hines solver to the older (slower) mode.
** Level 2 is the most optimized.
*/
int	hines_mode = 2

maxerrors 80

/*
** Loading in the prototypes
*/
if (!{exists(/library)})
		include defaults
		include compartments
		include bulbchan
	
		ce /library
	
		make_cylind_compartment
		make_LCa3_mit_usb
    	make_K2_mit_usb
    	make_K_mit_usb
		make_KA_bsg_yka
		set KA_bsg_yka Ek -0.07
		make_KM_bsg_upi
		set KM_bsg_upi Ek -0.07
		make_Na_mit_usb
		make_Na2_mit_usb
		make_Ca_mit_conc
		make_Kca_mit_usb
		ce /
end


/*
** Creating the cells 
*/
// Reading in the basic cell descriptor files 
read_cell {mitcell} /mit

// Setting up the hsolvers
if (hines_mode > 0)
	create hsolve /mit/solve
	set ^ path /mit/##[][TYPE=compartment]

	if (hines_mode == 1)
		set /#/solve comptmode 1 chanmode 1 useconcen 1
	end
	if (hines_mode == 2)
		set /#/solve comptmode 1 chanmode 3 useconcen 1
	end
	if (display_mode==4)
		set /#/solve comptmode 1 chanmode 1 useconcen 1
	end
	call /mit/solve SETUP
	setmethod 11
end

// Setting up the file I/O
create asc_file /output/mitVm
sendmsg /mit/#[][TYPE=compartment] /output/mitVm SAVE Vm
set	/output/# leave_open 1 initialize 1 flush 0
useclock /output/mitVm 1

// Seting up graphics
if (display_mode==1)
	xstartup
	create xform /gmit [0,700,800,180]
	create xgraph /gmit/graph [0%,0%,100%,100%]
	set /gmit/graph ymin -0.1 ymax 0.05 xmax {simtime}
	sendmsg /mit/soma /gmit/graph PLOT Vm *somaVm *red
	/*
	create xform /fmit [0,0,800,700]
	create xdraw /fmit/draw [0%,0%,100%,100%] 
	set ^ wx 0.003 wy 0.003 transform ortho3d vx 0 vy -18 vz 11
	create xcell /fmit/draw/cell
	set ^ path /mit/##[][TYPE=compartment] \
		colfield Vm autocol FALSE colmin -0.15 colmax 0.05
	set ^ autofat FALSE fatrange 0.0002
	set ^ rooticon soma.icon
	xshow /fmit
	*/
	xshow /gmit
	/*
	useclock /fmit 1
	*/
	useclock /gmit 1
end

function do_sim(time,inj)
	set /mit/soma inject {inj}
	call /mit/solve HPUT /mit/soma
	step -t {time}
end

// Running simulation
reset
do_sim({prestimtime},{const_inj})
do_sim({stimduration},{const_inj+bliphi})
do_sim({poststimtime},{const_inj})
do_sim({stimduration},{const_inj+bliplo})
do_sim({poststimtime},{const_inj})

// Flushing pending file output
set /output/mitVm flush 1 leave_open 0
call /output/mitVm PROCESS

// Displaying xplots in mode 2
if (display_mode==2)
	xplot mitVm -geometry =300x300+300+300 &
end

if (display_mode != 1)
	quit
end
