//genesis
/* 
** This simulation script performs 1 simulation :
** mitral cell, behaviour under voltage clamp near threshold
*/

/* Simulation parameters */
float dt = 10e-6
float grapht = 50e-6
float filet = 200e-6
float currt = 20e-6
setclock 0 {dt}
setclock 1 {filet}
setclock 2 {grapht}
setclock 3 {currt}
float prestimtime = 0.010
float stimduration = 0.250
float poststimtime = 0.0
float simtime = prestimtime+stimduration+poststimtime
str mitcell="mit.p"
float holding_potl = -0.0475

/* Display_mode selects how you want the output.
** 0 : Only file output
** 1 : Xodus output
** 2 : xplot output
*/
int display_mode = 1

/*
** hines_mode is a flag to select the level of optimization for the
** hsolver.
** Level 0 does not use the hines solver.
** Level 1 sets the hines solver to the older (slower) mode.
** Level 2 is the most optimized.
*/
int	hines_mode = 2

/*
** Loading in the prototypes
*/
if (!{exists(/library)})
		include defaults
		include compartments
		include bulbchan
		include vclamp
	
		ce /library
	
		make_cylind_compartment
		make_LCa3_mit_usb
    	make_K2_mit_usb
    	make_K_mit_usb
		make_KA_bsg_yka
		set KA_bsg_yka Ek -0.07
		make_KM_bsg_upi
		set KM_bsg_upi Ek -0.07
		make_Na_mit_usb
		make_Na2_mit_usb
		make_Ca_mit_conc
		make_Kca_mit_usb
		make_Vclamp
		ce /
end


/*
** Creating the cells 
*/
// Reading in the basic cell descriptor files 
read_cell {mitcell} /mit

/* Setting up the voltage clamp */
create neutral /dummy
copy /library/Vclamp /mit/soma
ce /mit/soma/Vclamp
set saturation 1.0e9
set PID gain 2e-6 saturation 1e9 tau_i {dt} tau_d {dt/4.0}

sendmsg /dummy lowpass INJECT x
sendmsg /mit/soma PID SNS Vm
sendmsg PID /mit/soma INJECT output


// Setting up the hsolvers
if (hines_mode > 0)
	create hsolve /mit/solve
	set ^ path /mit/##[][TYPE=compartment]

	if (hines_mode == 1)
		set /#/solve comptmode 1 chanmode 1 useconcen 1
	end
	if (hines_mode == 2)
		set /#/solve comptmode 1 chanmode 3 useconcen 1
	end
	/* Since we are updating the graphics so infrequently, it is
	** more effective to use the faster hines method and explicitly
	** ask it to update the cell values when we want to do graphics
	*/
	/*
	if (display_mode==1)
		set /#/solve comptmode 1 chanmode 1 useconcen 1
	end
	*/
	call /mit/solve SETUP
	setmethod 11
end

function do_update
	call /mit/solve HSAVE
end

// Setting up the file I/O
create asc_file /output/somaVm
create asc_file /output/glomVm
create asc_file /output/primVm
create asc_file /output/sec1Vm
create asc_file /output/sec1aVm
create asc_file /output/sec2Vm
create asc_file /output/sec3Vm
create asc_file /output/sec4Vm
create asc_file /output/axonVm
create asc_file /output/curr
set	/output/# leave_open 1 initialize 1 flush 0
useclock /output/# 1
create script_out /output/scout
set /output/scout command do_update
useclock /output/scout 1
useclock /output/curr 3

// Seting up graphics
if (display_mode==1)
	xstartup
	create xform /gmit [600,0,500,880]
	create xgraph /gmit/graph [0%,0%,100%,70%]
	create xgraph /gmit/curr [0%,70%,100%,30%]
	set /gmit/graph ymin -0.1 ymax 0.85 xmax {simtime} yoffset 0.1 
	set /gmit/curr ymin -2e-8 ymax 1e-8 xmax {simtime}
	sendmsg /mit/soma /gmit/graph PLOT Vm *somaVm *red
	sendmsg /mit/soma /output/somaVm SAVE Vm
	sendmsg /mit/axon[12] /gmit/graph PLOT Vm *somaVm *red
	sendmsg /mit/axon[12] /output/axonVm SAVE Vm
	sendmsg /mit/primary_dend[3] /gmit/graph PLOT Vm *primary *green
	sendmsg /mit/primary_dend[3] /output/primVm SAVE Vm
	sendmsg /mit/glom11 /gmit/graph PLOT Vm *somaVm *blue
	sendmsg /mit/glom11 /output/glomVm SAVE Vm
	sendmsg /mit/sec_dend11[4] /gmit/graph PLOT Vm *somaVm *orange
	sendmsg /mit/sec_dend11[4] /output/sec1Vm SAVE Vm
	sendmsg /mit/sec_dend12[4] /gmit/graph PLOT Vm *somaVm *blue
	sendmsg /mit/sec_dend12[4] /output/sec1Vm SAVE Vm
	sendmsg /mit/sec_dend21[4] /gmit/graph PLOT Vm *somaVm *hot25
	sendmsg /mit/sec_dend21[4] /output/sec2Vm SAVE Vm
	sendmsg /mit/sec_dend31[4] /gmit/graph PLOT Vm *somaVm *black
	sendmsg /mit/sec_dend31[4] /output/sec3Vm SAVE Vm
	sendmsg /mit/sec_dend41[4] /gmit/graph PLOT Vm *somaVm *hot49
	sendmsg /mit/sec_dend41[4] /output/sec4Vm SAVE Vm
	sendmsg /mit/soma/Vclamp/PID /gmit/curr PLOT output *current *red
	sendmsg /mit/soma/Vclamp/PID /output/curr SAVE output


	create xform /fmit [0,0,600,700]
	create xdraw /fmit/draw [0%,0%,100%,100%] 
	set ^ wx 0.003 wy 0.003 transform ortho3d vx 0 vy -18 vz 11
	create xcell /fmit/draw/cell
	set ^ path /mit/##[][TYPE=compartment] \
		colfield Vm autocol FALSE colmin -0.15 colmax 0.05
	set ^ autofat FALSE fatrange 0.0002
	set ^ rooticon soma.icon
	xshow /fmit
	xshow /gmit
	useclock /fmit/## 1
	useclock /gmit/## 2
end

// Running simulation
reset
set /dummy x -0.065
step -t {prestimtime}
set /dummy x {holding_potl}
step -t {stimduration}

// Flushing pending file output
set /output/#[OBJECT=asc_file] flush 1 leave_open 0
call /output/#[OBJECT=asc_file] PROCESS

// Displaying xplots in mode 2
if (display_mode==2)
end

if (display_mode != 1)
	quit
end
